@@ -8,7 +8,7 @@ package Strict::Perl;
 # Copyright (c) 2014, 2015, 2017 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$Strict::Perl::VERSION = 2017.03;
+$Strict::Perl::VERSION = 2017.04;
 
 use 5.00503;
 use strict;
@@ -17,7 +17,7 @@ local $^W = 1;
 # use strict;
 sub _strict {
     require strict;
-    if (($] < 5.006) and exists $INC{'Fake/Our.pm'}) {
+    if (exists $INC{'Fake/Our.pm'}) {
         # no strict qw(vars); on Fake::Our used
     }
     else {
@@ -51,7 +51,7 @@ sub _Fatal {
     }
 
     # not on Modern::Open
-    if (($] >= 5.006) or not exists $INC{'Modern/Open.pm'}) {
+    if (not exists $INC{'Modern/Open.pm'}) {
         for my $function (qw(open opendir sysopen pipe accept)) {
             _install_fatal_function($function, $package);
         }
@@ -291,86 +291,6 @@ sub import {
     if ($] >= 5.010001) {
         _autodie();
     }
-
-    my @mustword = qw(VERSION);
-    my %used = ();
-
-    # disable considered statements and variables
-    if (open(SCRIPT,$0)) {
-        @_ = <SCRIPT>;
-        close(SCRIPT);
-        my $line = 1;
-
-        # skip #line NNN
-        if (grep(/^[#]line\s+[0-9]+/x,@_)){
-            while ($_ = shift @_) {
-                $line++;
-                if (/^[#]line\s+[0-9]+/x) {
-                    last;
-                }
-            }
-        }
-
-        while ($_ = shift @_) {
-            if (/^__END__$/x) {
-                last;
-            }
-            if (/ (?<! [A-Za-z_0-9\$\@%&*':>] ) (
-                goto   | redo   | until    | foreach  |
-                format | write  | formline |
-                msgctl | msgget | msgrcv   | msgsnd   |
-                semctl | semget | semop    |
-                shmctl | shmget | shmread  | shmwrite |
-                given  | when
-
-            ) \b /x) { # Oops! I did little overkill.
-                die "Use of '$1' statement deprecated in line $line\n";
-            }
-            elsif (/ (
-                \$ARRAY_BASE \b                            | \$\[     |
-                                               \$OFMT \b   | \$\# (?![A-Za-z_\{]) |
-                                                             \@F \b   |
-                                                             \$\^H \b |
-
-                \$OUTPUT_FIELD_SEPARATOR \b  | \$OFS \b    | \$\,     |
-                \$OUTPUT_RECORD_SEPARATOR \b | \$ORS \b    | \$\\     |
-                \$LIST_SEPARATOR \b                        | \$\"     |
-                \$SUBSCRIPT_SEPARATOR \b     | \$SUBSEP \b | \$\;     |
-
-                \$MULTILINE_MATCHING \b                    | \$\*     |
-                \$PREMATCH \b                              | \$\`     |
-                \$MATCH \b                                 | \$\&     |
-                \$POSTMATCH \b                             | \$\'     |
-
-                \$FORMAT_PAGE_NUMBER \b                    | \$\%     |
-                \$FORMAT_LINES_PER_PAGE \b                 | \$\=     |
-                \$FORMAT_LINES_LEFT \b                     | \$\-     |
-                \$FORMAT_NAME \b                           | \$\~     |
-                \$FORMAT_TOP_NAME \b                       | \$\^ (?![A-Za-z_\{]) |
-                \$FORMAT_LINE_BREAK_CHARACTERS \b          | \$\: (?![:])         |
-                \$FORMAT_FORMFEED \b                       | \$\^L \b |
-                \$ACCUMULATOR \b                           | \$\^A \b
-
-            ) /x) {
-                die "Use of special variable '$1' deprecated in line $line\n";
-            }
-            elsif (/ ( ~~ ) /x) {
-                die "Use of operator '$1' deprecated in line $line\n";
-            }
-            for my $mustword (@mustword) {
-                if (/ \b $mustword \b /x) {
-                    $used{$mustword} = 1;
-                }
-            }
-            $line++;
-        }
-    }
-
-    for my $mustword (@mustword) {
-        if (not $used{$mustword}) {
-            die "'$mustword' not found in $0.\n";
-        }
-    }
 }
 
 1;
@@ -385,7 +305,7 @@ Strict::Perl - Perl module to restrict old/unsafe constructs
 
 =head1 SYNOPSIS
 
-  use Strict::Perl 2017.03; # must version, must match
+  use Strict::Perl 2017.04; # must version, must match
 
 =head1 DESCRIPTION
 
@@ -397,7 +317,7 @@ in your script.
 
 Version specify is required when use Strict::Perl, like;
 
-  use Strict::Perl 2017.03;
+  use Strict::Perl 2017.04;
 
 It's die if specified version doesn't match Strict::Perl's version.
 
@@ -460,52 +380,10 @@ On Perl 5.00503 or later,
       fork
   );
 
-Prohibited Keywords in your script are;
-
-  goto  redo  until  foreach
-  format  write  formline
-  msgctl  msgget  msgrcv  msgsnd
-  semctl  semget  semop
-  shmctl  shmget  shmread  shmwrite
-  given  when
-
-Prohibited Special Variables are;
-
-  $ARRAY_BASE                        $[
-  $OFMT                              $#
-                                     @F
-                                     $^H
-  $OUTPUT_FIELD_SEPARATOR   $OFS     $,
-  $OUTPUT_RECORD_SEPARATOR  $ORS     $\
-  $LIST_SEPARATOR                    $"
-  $SUBSCRIPT_SEPARATOR      $SUBSEP  $;
-  $MULTILINE_MATCHING                $*
-  $PREMATCH                          $`
-  $MATCH                             $&
-  $POSTMATCH                         $'
-  $FORMAT_PAGE_NUMBER                $%
-  $FORMAT_LINES_PER_PAGE             $=
-  $FORMAT_LINES_LEFT                 $-
-  $FORMAT_NAME                       $~
-  $FORMAT_TOP_NAME                   $^
-  $FORMAT_LINE_BREAK_CHARACTERS      $:
-  $FORMAT_FORMFEED                   $^L
-  $ACCUMULATOR                       $^A
-
-Prohibited Operator is;
-
-  ~~ (smartmatch)
-
 Prohibited modules in script are;
 
   Thread  threads  encoding  Switch
 
-Must Keyword in your script is;
-
-  VERSION
-  Any of scalar variable or any variable, subroutine name,
-  literal string, or comment
-
 Be useful software for you!
 
 =head1 AUTHOR
